internal

package
v0.0.0-...-3f1a620 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: BSD-2-Clause Imports: 4 Imported by: 0

Documentation

Overview

Package internal contains unstable code.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Messager

type Messager interface {
	Message() string
}

Messager is an interface for lazy message construction.

func MsgFmt

func MsgFmt(msg string, args ...any) Messager

MsgFmt constructs a message from fmt.Sprintf-like arguments.

type MsgString

type MsgString string

MsgString implements Messager for a simple string message.

func (MsgString) Message

func (m MsgString) Message() string

Message implements Messager.

type TestTB

type TestTB struct {
	W io.Writer
}

TestTB implements [shoulda.TB] and [musta.TB] for testing and examples.

func (TestTB) Fail

func (t TestTB) Fail()

Fail implements [shoulda.TB.Helper] and [musta.TB.Helper].

func (TestTB) FailNow

func (t TestTB) FailNow()

FailNow implements [shoulda.TB.Helper] and [musta.TB.Helper] by doing nothing.

func (TestTB) Helper

func (t TestTB) Helper()

Helper implements [shoulda.TB.Helper] and [musta.TB.Helper] by doing nothing.

func (TestTB) Log

func (t TestTB) Log(args ...any)

Log implements [shoulda.TB.Helper] and [musta.TB.Helper].

Directories

Path Synopsis
Package diffa provides a self-contained unified diff library that is as simple as possible, but not simpler.
Package diffa provides a self-contained unified diff library that is as simple as possible, but not simpler.
Package main generates the musta wrappers and mirrored tests.
Package main generates the musta wrappers and mirrored tests.

Jump to