Documentation
¶
Overview ¶
Package internal contains unstable code.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Messager ¶
type Messager interface {
Message() string
}
Messager is an interface for lazy message construction.
type TestTB ¶
TestTB implements [shoulda.TB] and [musta.TB] for testing and examples.
func (TestTB) Fail ¶
func (t TestTB) Fail()
Fail implements [shoulda.TB.Helper] and [musta.TB.Helper].
func (TestTB) FailNow ¶
func (t TestTB) FailNow()
FailNow implements [shoulda.TB.Helper] and [musta.TB.Helper] by doing nothing.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package diffa provides a self-contained unified diff library that is as simple as possible, but not simpler.
|
Package diffa provides a self-contained unified diff library that is as simple as possible, but not simpler. |
|
Package main generates the musta wrappers and mirrored tests.
|
Package main generates the musta wrappers and mirrored tests. |
Click to show internal directories.
Click to hide internal directories.